;;; initmel -*- lexical-binding: t; -*-

;; This file controls what Doom modules are enabled and what order they load
;; in. Remember to run 'doom sync' after modifying it!

;; NOTE Press 'SPC h d h' (or 'C-h d h' for non-vim users) to access Doom's
;;      documentation. There you'll find a "Module Index" link where you'll find
;;      a comprehensive list of Doom's modules and what flags they support.

;; NOTE Move your cursor over a module's name (or its flags) and press 'K' (or
;;      'C-c c k' for non-vim users) to view its documentation. This works on
;;      flags as well (those symbols that start with a plus).
;;
;;      Alternatively, press 'gd' (or 'C-c c d') on a module to browse its
;;      directory (for easy access to its source code).

(defvar work-systems '("HLXLAP001"))
(defvar IS-TERMUX (getenv "TERMUX_VERSION"))
(defvar IS-WORK (or (member (system-name) work-systems) IS-TERMUX))
(defvar IS-DEV (not IS-TERMUX))

(doom! :completion
       (company +childframe)           ; the ultimate code completion backend
       (vertico +icons)  ; the search engine of the future

       :ui
       doom                     ; what makes DOOM look the way it does
       doom-dashboard           ; a nifty splash screen for Emacs
       doom-quit                ; DOOM quit-message prompts when you quit Emacs
       hl-todo                  ; highlight TODO/FIXME/NOTE/DEPRECATED/HACK/REVIEW
       indent-guides            ; highlighted indent columns
       nav-flash                ; blink cursor line after big motions
       ophints                  ; highlight the region an operation acts on
       (popup +defaults)        ; tame sudden yet inevitable temporary windows
       vc-gutter                ; vcs diff in the fringe
       vi-tilde-fringe          ; fringe tildes to mark beyond EOB
       (window-select +numbers) ; visually switch windows
       (treemacs +lsp)
       workspaces               ; tab emulation, persistence & separate workspaces

       :editor
       (evil +everywhere)       ; come to the dark side, we have cookies
       file-templates           ; auto-snippets for empty files
       fold                     ; (nigh) universal code folding
       snippets                 ; my elves. They type so I don't have to

       :emacs
       (dired +icons +ranger)   ; making dired pretty [functional]
       electric                 ; smarter, keyword-based electric-indent
       (ibuffer +icons)         ; interactive buffer management
       undo                     ; persistent, smarter undo for your inevitable mistakes
       vc                       ; version-control and Emacs, sitting in a tree

       :term
       vterm    ; the best terminal emulation in Emacs

       :checkers
       syntax              ; tasing you for every semicolon you forget
       ;;(spell +flyspell) ; tasing you for misspelling mispelling
       ;;grammar           ; tasing grammar mistake every you make

       :tools
       (:if IS-DEV ansible)
       (:if IS-DEV (debugger +lsp))     ; FIXME stepping through code, to help you add bugs
       (:if IS-DEV direnv)
       (:if IS-DEV docker)
       editorconfig                     ; let someone else argue about tabs vs spaces
       (eval +overlay)                  ; run code, run (also, repls)
       lookup                           ; navigate your code and its documentation
       (:if IS-DEV lsp)
       (:if IS-DEV magit)               ; a git porcelain for Emacs
       (:if IS-DEV taskrunner)          ; taskrunner for all your projects
       (:if IS-DEV terraform)           ; infrastructure as code

       :os
       (:if IS-MAC macos)       ; improve compatibility with macOS
       tty                      ; improve the terminal Emacs experience

       :lang
       (:if IS-DEV (csharp +lsp         ; unity, .NET, and mono shenanigans
                           +dotnet))
       nix
       data                             ; config/data formats
       emacs-lisp                       ; drown in parentheses
       (:if IS-DEV (gdscript +lsp))     ; the language you waited for
       (:if IS-DEV (javascript +lsp))          ; all(hope(abandon(ye(who(enter(here))))))
       markdown                         ; writing docs for people to ignore
       org                              ; organize your plain life in plain text
       (:if IS-DEV (rust +lsp))         ; Fe2O3.unwrap().unwrap().unwrap().unwrap()
       sh                               ; she sells {ba,z,fi}sh shells on the C xor
       web                              ; the tubes
       (:if IS-DEV (yaml +lsp))                ; JSON, but readable

       :app
       (rss +org)        ; emacs as an RSS reader

       :config
       (default +bindings +smartparens))
